@@ -1,9 +1,8 @@
 from pynamodb.attributes import UnicodeAttribute, ListAttribute
 
+from modular_sdk.models.pynamongo.models import ModularBaseModel
 from modular_sdk.models.base_meta import BaseMeta, TABLES_PREFIX
-from modular_sdk.models.pynamodb_extension.base_model import M3BooleanAttribute
-from modular_sdk.models.pynamodb_extension.base_role_access_model import \
-    BaseRoleAccessModel
+from modular_sdk.models.pynamongo.attributes import M3BooleanAttribute
 
 NAME_KEY = 'n'
 DISPLAY_NAME_KEY = 'dn'
@@ -13,7 +12,7 @@ ACTIVE = 'act'
 MODULAR_CUSTOMERS_TABLE_NAME = 'Customers'
 
 
-class Customer(BaseRoleAccessModel):
+class Customer(ModularBaseModel):
     class Meta(BaseMeta):
         table_name = f'{TABLES_PREFIX}{MODULAR_CUSTOMERS_TABLE_NAME}'
 
