@@ -2,13 +2,13 @@ from pynamodb.attributes import UnicodeAttribute, MapAttribute, \
     UTCDateTimeAttribute
 from pynamodb.indexes import AllProjection
 
-from modular_sdk.models.pynamodb_extension.base_model import BaseGSI
-from modular_sdk.models.pynamodb_extension.base_role_access_model import \
-    BaseRoleAccessModel
+from pynamodb.indexes import GlobalSecondaryIndex
+from modular_sdk.models.pynamongo.models import ModularBaseModel
+
 from modular_sdk.models.base_meta import BaseMeta
 
 
-class JobStartedAtIndex(BaseGSI):
+class JobStartedAtIndex(GlobalSecondaryIndex):
     class Meta:
         index_name = "job-started_at-index"
         read_capacity_units = 1
@@ -19,15 +19,15 @@ class JobStartedAtIndex(BaseGSI):
     started_at = UnicodeAttribute(range_key=True)
 
 
-class Job(BaseRoleAccessModel):
+class Job(ModularBaseModel):
     class Meta(BaseMeta):
         table_name = 'ModularJobs'
 
     job = UnicodeAttribute(hash_key=True)
     job_id = UnicodeAttribute(range_key=True)
     application = UnicodeAttribute()
-    started_at = UTCDateTimeAttribute()
-    stopped_at = UTCDateTimeAttribute(null=True)
+    started_at = UnicodeAttribute()
+    stopped_at = UnicodeAttribute(null=True)
     state = UnicodeAttribute()
     error_type = UnicodeAttribute(null=True)
     error_reason = UnicodeAttribute(null=True)
